@@ -8,6 +8,11 @@ import collections
 import pytz
 from datetime import datetime, timedelta
 
+try:
+    from jaws import tilt_angle, fsds_adjust
+except ImportError:
+    import tilt_angle, fsds_adjust
+
 ###############################################################################
 
 freezing_point_temp = 273.15
@@ -16,7 +21,7 @@ seconds_in_hour = 3600
 seconds_in_half_hour = 1800
 fillvalue_double = 9.969209968386869e+36
 fillvalue_float = 9.96921e+36
-jaws_version = '0.7.5'
+jaws_version = '0.7.7'
 
 ###############################################################################
 
@@ -128,7 +133,7 @@ def load_dataset_attributes(name, ds, args, **kwargs):
     ds.attrs['JAWS'] = 'Justified Automated Weather Station software version {} (Homepage = https://github.com/' \
                        'jaws/jaws)'.format(jaws_version)
 
-    derived_vars = ['time', 'time_bounds', 'sza', 'az','station_name', 'latitude', 'longitude', 'surface_temp',
+    derived_vars = ['time', 'time_bounds', 'sza', 'az','station_name', 'latitude', 'longitude',
                     'ice_velocity_GPS_total', 'ice_velocity_GPS_x', 'ice_velocity_GPS_y', 'height']
 
     no_drv_tm_vars = []
@@ -235,6 +240,29 @@ def get_cleardays_df(station_name, first_date, last_date):
     return clr_df
 
 
+def call_rigb(args, station_name, first_date, last_date, ds, latitude, longitude, rigb_vars):
+    log(args, 6, 'Detecting clear-sky day(s)')
+    clr_df = get_cleardays_df(station_name, first_date, last_date)
+    if args.dbg_lvl > 6:
+        print("Found {} clear-sky day(s)".format(len(clr_df.index)))
+
+    if clr_df.empty:
+        if args.dbg_lvl > 6:
+            print('Skipping RIGB, since no clear-sky day found')
+    else:
+        log(args, 7, 'Calculating tilt angle and direction')
+        if len(clr_df.index) >= 5:
+            print('Tilt correction will take long time')
+        ds = tilt_angle.main(ds, latitude, longitude, clr_df, args)
+
+        log(args, 8, 'Calculating corrected_fsds')
+        ds = fsds_adjust.main(ds, args)
+
+        rigb_vars = ['tilt_direction', 'tilt_angle', 'fsds_adjusted', 'fsus_adjusted', 'cloud_fraction']
+
+    return ds, rigb_vars
+
+
 def write_data(args, ds, op_file, encoding):
     if args.format3 == 1:
         ds.to_netcdf(op_file, format='NETCDF3_CLASSIC', unlimited_dims={'time': True}, encoding=encoding)
