@@ -116,6 +116,8 @@ def get_time_and_sza(args, dataframe, longitude, latitude):
     return month, day, hour, minutes, time, time_bounds, sza, az, first_date, last_date
 
 
+# Just a framework, need to do calculations
+'''
 def extrapolate_temp(dataframe):
     ht1 = dataframe['wind_sensor_height_1']
     ht2 = dataframe['wind_sensor_height_2']
@@ -124,6 +126,7 @@ def extrapolate_temp(dataframe):
 
     surface_temp = temp_ht1 - (((temp_ht2 - temp_ht1)/(ht2 - ht1))*ht1)
     return surface_temp
+'''
 
 
 def gcnet2nc(args, input_file, output_file, stations):
@@ -134,7 +137,7 @@ def gcnet2nc(args, input_file, output_file, stations):
     ds = xr.Dataset.from_dataframe(df)
     ds = ds.drop('time')
 
-    surface_temp = extrapolate_temp(df)
+    # surface_temp = extrapolate_temp(df)
 
     common.log(args, 2, 'Retrieving latitude, longitude and station name')
     latitude, longitude, station_name = get_station(args, input_file, stations)
@@ -162,21 +165,12 @@ def gcnet2nc(args, input_file, output_file, stations):
     ds['station_name'] = tuple(), station_name
     ds['latitude'] = tuple(), latitude
     ds['longitude'] = tuple(), longitude
-    ds['surface_temp'] = 'time', surface_temp
+    # ds['surface_temp'] = 'time', surface_temp
 
     rigb_vars = []
     if args.rigb:
-        common.log(args, 6, 'Detecting clear days')
-        clr_df = common.get_cleardays_df(station_name, first_date, last_date)
-
-        if not clr_df.empty:
-            common.log(args, 7, 'Calculating tilt angle and direction')
-            ds = tilt_angle.main(ds, latitude, longitude, clr_df, args)
-
-            common.log(args, 8, 'Calculating corrected_fsds')
-            ds = fsds_adjust.main(ds, args)
-
-            rigb_vars = ['tilt_direction', 'tilt_angle', 'fsds_adjusted', 'fsus_adjusted', 'cloud_fraction']
+        ds, rigb_vars = common.call_rigb(
+            args, station_name, first_date, last_date, ds, latitude, longitude, rigb_vars)
 
     comp_level = args.dfl_lvl
 
